@@ -14,7 +14,7 @@ use DBD::SQLite  1.27 ();
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.46';
+	$VERSION = '1.47';
 }
 
 # Support for the 'prune' option
@@ -82,6 +82,9 @@ sub import {
 	unless ( defined $params{tables} ) {
 		$params{tables} = 1;
 	}
+	unless ( defined $params{views} ) {
+		$params{views} = 0;
+	}
 	unless ( defined $params{x_update} ) {
 		$params{x_update} = 0;
 	}
@@ -169,11 +172,6 @@ sub import {
 	my $cleanup    = $params{cleanup};
 	my $xsaccessor = $params{xsaccessor};
 	my $array      = $params{array};
-	my $xsclass    = $array ? 'Class::XSAccessor::Array' : 'Class::XSAccessor';
-	my $l          = $array ? '['  : '{';
-	my $r          = $array ? ']'  : '}';
-	my $slice      = $array ? '{}' : '{ Slice => {} }';
-	my $rowref     = $array ? 'arrayref' : 'hashref';
 
 	# Generate the support package code
 	my $code = <<"END_PERL";
@@ -355,8 +353,8 @@ END_PERL
 	if ( $params{tables} ) {
 		# Capture the raw schema table information
 		my $tables = $dbh->selectall_arrayref(
-			'select * from sqlite_master where name not like ? and type = ?',
-			{ Slice => {} }, 'sqlite_%', 'table',
+			'select * from sqlite_master where name not like ? and type in ( ?, ? )',
+			{ Slice => {} }, 'sqlite_%', 'table', 'view',
 		);
 		my %tindex = map { $_->{name} => $_ } @$tables;
 
@@ -379,8 +377,17 @@ END_PERL
 			# Convenience escaping for the column names
 			$_->{qname} = "\"$_->{name}\"" foreach @$columns;
 
+			# Track array vs hash implementation on a per-table
+			# basis so that we can force views to always be done
+			# array-wise (to compensate for some weird SQLite
+			# column quoting differences between tables and views
+			$table->{array} = $array;
+			if ( $table->{type} eq 'view' ) {
+				$table->{array} = 1;
+			}
+
 			# Generate the object keys for the columns
-			if ( $array ) {
+			if ( $table->{array} ) {
 				foreach my $i ( 0 .. $#$columns ) {
 					$columns->[$i]->{xs}    = $i;
 					$columns->[$i]->{key}   = "[$i]";
@@ -411,8 +418,9 @@ END_PERL
 
 			# Generate the new Perl fragments
 			$table->{pl_new} = join "\n", map {
-				$array ? "\t\t\$attr{$_->{name}},"
-				       : "\t\t$_->{name} => \$attr{$_->{name}},"
+				$table->{array}
+					? "\t\t\$attr{$_->{name}},"
+					: "\t\t$_->{name} => \$attr{$_->{name}},"
 			} @$columns;
 
 			$table->{pl_insert} = join "\n", map {
@@ -458,6 +466,9 @@ END_PERL
 		# Generate the per-table code
 		foreach my $table ( @$tables ) {
 			my @columns = @{$table->{columns}};
+			my $slice   = $table->{array}
+				? '{}'
+				: '{ Slice => {} }';
 
 			# Generate the elements in all packages
 			$code .= <<"END_PERL";
@@ -493,7 +504,7 @@ sub count {
 END_PERL
 
 			# Handle different versions, because arrayref acts funny
-			if ( $array ) {
+			if ( $table->{array} ) {
 				$code .= <<"END_PERL";
 sub iterate {
 	my \$class = shift;
@@ -531,7 +542,7 @@ END_PERL
 
 			# Add the primary key based single object loader
 			if ( $table->{pks} ) {
-				if ( $array ) {
+				if ( $table->{array} ) {
 					$code .= <<"END_PERL";
 sub load {
 	my \$class = shift;
@@ -566,6 +577,8 @@ END_PERL
 
 			# Generate the elements for tables with primary keys
 			if ( $table->{create} ) {
+				my $l = $table->{array} ? '['  : '{';
+				my $r = $table->{array} ? ']'  : '}';
 				$code .= <<"END_PERL";
 sub new {
 	my \$class = shift;
@@ -610,7 +623,7 @@ sub truncate {
 END_PERL
 			}
 
-			if ( $table->{create} and $array ) {
+			if ( $table->{create} and $table->{array} ) {
 				# Add an additional set method to avoid having
 				# the user have to enter manual positions.
 				$code .= <<"END_PERL";
@@ -628,7 +641,11 @@ END_PERL
 
 			# Generate the boring accessors
 			if ( $xsaccessor ) {
-				my $type = $table->{create} ? 'accessors' : 'getters';
+				my $type    = $table->{create} ? 'accessors' : 'getters';
+				my $xsclass = $table->{array}
+					? 'Class::XSAccessor::Array'
+					: 'Class::XSAccessor';
+
 				$code .= <<"END_PERL";
 use $xsclass 1.05 {
 	getters => {
@@ -657,7 +674,7 @@ END_PERL
 				my @pk    = map { $_->{name} } @{$table->{pk}};
 				my $wsql  = join ' and ', map { "\"$_\" = ?" } @pk;
 				my $wattr = join ', ',    map { "\$self->$_" } @pk;
-				my $set   = $array
+				my $set   = $table->{array}
 					? '$self->set( $_ => $set{$_} ) foreach keys %set;'
 					: '$self->{$_} = $set{$_} foreach keys %set;';
 				$code .= <<"END_PERL";
@@ -680,9 +697,22 @@ sub update {
 }
 END_PERL
 			}
-
 		}
 	}
+
+	# Optionally generate the table classes
+	if ( $params{views} ) {
+		# Capture the raw schema table information
+		my $views = $dbh->selectall_arrayref(
+			'select * from sqlite_master where name not like ? and type = ?',
+			{ Slice => {} }, 'sqlite_%', 'view',
+		);
+		my %vindex = map { $_->{name} => $_ } @$views;
+
+		1;
+	}
+
+	# We are finished with it now
 	$dbh->disconnect;
 
 	# Add any custom code to the end
